@@ -5,11 +5,67 @@ import os
 import os.path
 import inspect
 import tuned.consts as consts
+import random
+import string
+import threading
+try:
+	from StringIO import StringIO
+except:
+	from io import StringIO
 
 __all__ = ["get"]
 
 root_logger = None
 
+log_handlers = {}
+log_handlers_lock = threading.Lock()
+
+class LogHandler(object):
+	def __init__(self, handler, stream):
+		self.handler = handler
+		self.stream = stream
+
+def _random_string(length):
+	r = random.SystemRandom()
+	chars = string.ascii_letters + string.digits
+	res = ""
+	for i in range(length):
+		res += random.choice(chars)
+	return res
+
+def log_capture_start(log_level):
+	with log_handlers_lock:
+		for i in range(10):
+			token = _random_string(16)
+			if token not in log_handlers:
+				break
+		else:
+			return None
+		stream = StringIO()
+		handler = logging.StreamHandler(stream)
+		handler.setLevel(log_level)
+		formatter = logging.Formatter(
+				"%(levelname)-8s %(name)s: %(message)s")
+		handler.setFormatter(formatter)
+		root_logger.addHandler(handler)
+		log_handler = LogHandler(handler, stream)
+		log_handlers[token] = log_handler
+		root_logger.debug("Added log handler %s." % token)
+		return token
+
+def log_capture_finish(token):
+	with log_handlers_lock:
+		try:
+			log_handler = log_handlers[token]
+		except KeyError:
+			return None
+		content = log_handler.stream.getvalue()
+		log_handler.stream.close()
+		root_logger.removeHandler(log_handler.handler)
+		del log_handlers[token]
+		root_logger.debug("Removed log handler %s." % token)
+		return content
+
 def get():
 	global root_logger
 	if root_logger is None:
@@ -36,15 +92,12 @@ class TunedLogger(logging.getLoggerClass()):
 	_file_handler = None
 
 	def __init__(self, *args, **kwargs):
-		super(self.__class__, self).__init__(*args, **kwargs)
+		super(TunedLogger, self).__init__(*args, **kwargs)
 		self.setLevel(logging.INFO)
 		self.switch_to_console()
 
-	def set_level(self, level, default = logging.NOTSET):
-		"""Set logging level. The 'level' parameter can be str or logging module constant."""
-		if type(level) is str:
-			level = logging._levelNames.get(level.upper(), logging.NOTSET)
-		self.level = level
+	def console(self, msg, *args, **kwargs):
+		self.log(consts.LOG_LEVEL_CONSOLE, msg, *args, **kwargs)
 
 	def switch_to_console(self):
 		self._setup_console_handler()
@@ -84,5 +137,6 @@ class TunedLogger(logging.getLoggerClass()):
 			filename, maxBytes = consts.LOG_FILE_MAXBYTES, backupCount = consts.LOG_FILE_COUNT)
 		cls._file_handler.setFormatter(cls._formatter)
 
+logging.addLevelName(consts.LOG_LEVEL_CONSOLE, consts.LOG_LEVEL_CONSOLE_NAME)
 logging.setLoggerClass(TunedLogger)
 atexit.register(logging.shutdown)
