@@ -1,6 +1,6 @@
 import os
 import tuned.logs
-import base
+from . import base
 from tuned.utils.commands import commands
 
 log = tuned.logs.get()
@@ -12,10 +12,10 @@ class cpulist_online(base.Function):
 	"""
 	def __init__(self):
 		# arbitrary number of arguments
-		super(self.__class__, self).__init__("cpulist_online", 0)
+		super(cpulist_online, self).__init__("cpulist_online", 0)
 
 	def execute(self, args):
-		if not super(self.__class__, self).execute(args):
+		if not super(cpulist_online, self).execute(args):
 			return None
 		cpus = self._cmd.cpulist_unpack(",".join(args))
 		online = self._cmd.cpulist_unpack(self._cmd.read_file("/sys/devices/system/cpu/online"))
