@@ -1,6 +1,6 @@
 import os
 import tuned.logs
-import base
+from . import base
 from tuned.utils.commands import commands
 
 log = tuned.logs.get()
@@ -11,9 +11,9 @@ class hex2cpulist(base.Function):
 	"""
 	def __init__(self):
 		# one argument
-		super(self.__class__, self).__init__("hex2cpulist", 1)
+		super(hex2cpulist, self).__init__("hex2cpulist", 1)
 
 	def execute(self, args):
-		if not super(self.__class__, self).execute(args):
+		if not super(hex2cpulist, self).execute(args):
 			return None
 		return ",".join(str(v) for v in self._cmd.hex2cpulist(args[0]))
