@@ -1,6 +1,6 @@
 import os
 import tuned.logs
-import base
+from . import base
 from tuned.utils.commands import commands
 
 class s2kb(base.Function):
@@ -9,10 +9,10 @@ class s2kb(base.Function):
 	"""
 	def __init__(self):
 		# one argument
-		super(self.__class__, self).__init__("s2kb", 1)
+		super(s2kb, self).__init__("s2kb", 1)
 
 	def execute(self, args):
-		if not super(self.__class__, self).execute(args):
+		if not super(s2kb, self).execute(args):
 			return None
 		try:
 			return str(int(args[0]) / 2)
